/// <reference path="./geolib.d.ts" />
/// <reference path="../typings/main.d.ts" />
var geolib = require("geolib");
function convertPoint(latLng) {
    return {
        latitude: latLng.lat,
        longitude: latLng.lng
    };
}
function getLayerType(layer) {
    if (layer instanceof L.Circle) {
        return "circle";
    }
    else if (layer instanceof L.Polygon) {
        if (layer instanceof L.Rectangle) {
            return "rectangle";
        }
        else {
            return "polygon";
        }
    } // else return undefined
}
function leafletLayerToLatLngFilter(layer, layerType) {
    if (layerType === void 0) { layerType = getLayerType(layer); }
    if (layerType === "circle") {
        var circle = layer;
        return function (latLng) { return geolib.isPointInCircle(convertPoint(latLng), convertPoint(circle.getLatLng()), circle.getRadius()); }; // note in meters
    }
    else if (layerType === "rectangle" || layerType === "polygon") {
        var polygon = layer;
        return function (latLng) { return geolib.isPointInside(convertPoint(latLng), polygon.getLatLngs().map(convertPoint)); };
    }
    else {
        // possibly polyline or marker, which should always return false
        return function () { return false; };
    }
}
exports.leafletLayerToLatLngFilter = leafletLayerToLatLngFilter;
function leafletLayerGroupToLatLngFilter(layerGroup) {
    var predicates = layerGroup.getLayers().map(function (layer) { return leafletLayerToLatLngFilter(layer); });
    return function (latLng) {
        for (var _i = 0; _i < predicates.length; _i++) {
            var predicate = predicates[_i];
            if (predicate(latLng)) {
                return true;
            }
        }
        return false;
    };
}
exports.leafletLayerGroupToLatLngFilter = leafletLayerGroupToLatLngFilter;
//# sourceMappingURL=geoFilter.js.map